@@ -6,7 +6,7 @@
  * 
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  * 
  * GNU Radio is distributed in the hope that it will be useful,
@@ -34,10 +34,16 @@
  * complement of the final running CRC.  The resulting CRC should be
  * transmitted in big endian order.
  */
-unsigned int gr_update_crc32(unsigned int crc, const unsigned char *buf, int len);
-unsigned int gr_update_crc32(unsigned int crc, const std::string buf);
+unsigned int 
+gr_update_crc32(unsigned int crc, const unsigned char *buf, size_t len);
 
-unsigned int gr_crc32(const unsigned char *buf, int len);
-unsigned int gr_crc32(const std::string buf);
+unsigned int 
+gr_update_crc32(unsigned int crc, const std::string buf);
+
+unsigned int 
+gr_crc32(const unsigned char *buf, size_t len);
+
+unsigned int 
+gr_crc32(const std::string buf);
 
 #endif /* INCLUDED_CRC32_H */
