@@ -6,7 +6,7 @@
  * 
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  * 
  * GNU Radio is distributed in the hope that it will be useful,
@@ -24,7 +24,7 @@
 #include <fusb_win32.h>
 
 static const int MAX_BLOCK_SIZE = 64 * 1024;		// Windows kernel hard limit
-static const int FUSB_BUFFER_SIZE = 2 * (1L << 20);	// 2 MB (was 8 MB)
+static const int FUSB_BUFFER_SIZE = 2 * (1L << 20);	// 2 MB
 	
 fusb_devhandle *
 fusb_sysconfig::make_devhandle (usb_dev_handle *udh)
@@ -37,6 +37,11 @@ int fusb_sysconfig::max_block_size ()
   return MAX_BLOCK_SIZE;
 }
 
+int fusb_sysconfig::default_block_size ()
+{
+  return fusb_sysconfig::max_block_size ();
+}
+
 int fusb_sysconfig::default_buffer_size ()
 {
   return FUSB_BUFFER_SIZE;
